URL = "https://www.yourselfquotes.com/thought-of-the-day/"
CONN_URL = "www.google.com"
SERIES_QUOTES_URL = "https://www.tvtime.com/article/top-50-unforgettable-tv-quotes"
ANIME_QUOTES_URL = "https://bayart.org/anime-quotes/"